==> aws-android-sdk-cognito-2.1.7-sources.jar: main/java/com/amazonaws/services/autoscaling/model/transform/AdjustmentTypeStaxUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Adjustment Type StAX Unmarshaller
 */
public class AdjustmentTypeStaxUnmarshaller implements Unmarshaller<AdjustmentType, StaxUnmarshallerContext> {

    public AdjustmentType unmarshall(StaxUnmarshallerContext context) throws Exception {
        AdjustmentType adjustmentType = new AdjustmentType();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return adjustmentType;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("AdjustmentType", targetDepth)) {
                    adjustmentType.setAdjustmentType(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return adjustmentType;
                }
            }
        }
    }

    private static AdjustmentTypeStaxUnmarshaller instance;
    public static AdjustmentTypeStaxUnmarshaller getInstance() {
        if (instance == null) instance = new AdjustmentTypeStaxUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognito-2.1.10-sources.jar: main/java/com/amazonaws/services/autoscaling/model/transform/AdjustmentTypeStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import org.xmlpull.v1.XmlPullParser;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Adjustment Type StAX Unmarshaller
 */
public class AdjustmentTypeStaxUnmarshaller implements Unmarshaller<AdjustmentType, StaxUnmarshallerContext> {

    public AdjustmentType unmarshall(StaxUnmarshallerContext context) throws Exception {
        AdjustmentType adjustmentType = new AdjustmentType();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            int xmlEvent = context.nextEvent();
            if (xmlEvent == XmlPullParser.END_DOCUMENT) return adjustmentType;

            if (xmlEvent == XmlPullParser.START_TAG) {
                if (context.testExpression("AdjustmentType", targetDepth)) {
                    adjustmentType.setAdjustmentType(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent == XmlPullParser.END_TAG) {
                if (context.getCurrentDepth() < originalDepth) {
                    return adjustmentType;
                }
            }
        }
    }

    private static AdjustmentTypeStaxUnmarshaller instance;
    public static AdjustmentTypeStaxUnmarshaller getInstance() {
        if (instance == null) instance = new AdjustmentTypeStaxUnmarshaller();
        return instance;
    }
}
